==> cons-commons-1.0.70.tgz: package/lib/entities/visit/farm.type.ts <==
import { InventoryItem } from './../financial/inventory/inventoryItem.type';
import { Animal } from './../zootechnical/animal.type';
import { Expense } from './../financial/expense.type';
import { Address } from '../app/address.type';
import { DairyCompany } from './dairyCompany.type';
import { Entity, Column,ManyToOne ,JoinColumn, OneToMany, JoinTable, OneToOne} from 'typeorm';
import { BasicREntity } from '../basicR.type';
import { IsString, IsNotEmpty, IsOptional, IsDefined } from 'class-validator';
import { UserFarmRole } from './userFarmRole.type';
import { Agreement } from './agreement.type';
import { Revenue } from '../financial/revenue.type';

@Entity()
export class Farm extends BasicREntity {

  @IsString()
  @IsNotEmpty()
  @Column({ nullable: false })
  name: string;

  @IsDefined()
  @OneToOne(type => Address, { nullable: false, cascade: true })
  @JoinColumn()
  address: Address;

  @IsOptional()
  @OneToMany(type => Agreement, agreement => agreement.farm, { nullable: true })
  agreements?: Agreement[];

  @IsOptional()
  @OneToMany(type => UserFarmRole, userFarmRole => userFarmRole.farm, { nullable: true })
  owners?: UserFarmRole[];

  @IsOptional()
  @OneToMany(type => UserFarmRole, userFarmRole => userFarmRole.farm, { nullable: true })
  consultants?: UserFarmRole[];

  @IsOptional()
  @ManyToOne(type => DairyCompany, dairyCompany => dairyCompany.farms, { nullable: true })
  dairyCompany?: DairyCompany;

  @IsOptional()
  @OneToMany(type => UserFarmRole, userFarmRole => userFarmRole.user, { nullable: true })
  userFarmRoles?: UserFarmRole[];

  @IsOptional()
  @OneToMany(type => Expense, expense => expense.farm, { nullable: true })
  expenses?: Expense[];

  @IsOptional()
  @OneToMany(type => InventoryItem, inventoryItem => inventoryItem.farm, { nullable: true })
  inventoryItems?: InventoryItem[];

  @IsOptional()
  @OneToMany(type => Animal, animal => animal.farm, { nullable: true })
  animals?: Animal[];

  @IsOptional()
  @OneToMany(type => Revenue, revenue => revenue.farm, { nullable: false })
  revenues?: Revenue[];
}

==> cons-commons-1.0.72.tgz: package/lib/entities/visit/farm.type.ts <==
import { UserConsultant } from './userConsultant.type';
import { UserFarmer } from './userFarmer.type';
import { InventoryItem } from './../financial/inventory/inventoryItem.type';
import { Animal } from './../zootechnical/animal.type';
import { Expense } from './../financial/expense.type';
import { Address } from '../app/address.type';
import { DairyCompany } from './dairyCompany.type';
import { Entity, Column, ManyToOne, JoinColumn, OneToMany, JoinTable, OneToOne, ManyToMany } from 'typeorm';
import { BasicREntity } from '../basicR.type';
import { IsString, IsNotEmpty, IsOptional, IsDefined } from 'class-validator';
import { Agreement } from './agreement.type';
import { Revenue } from '../financial/revenue.type';

@Entity()
export class Farm extends BasicREntity {

  @IsString()
  @IsNotEmpty()
  @Column({ nullable: false })
  name: string;

  @IsDefined()
  @OneToOne(type => Address, { nullable: false, cascade: true })
  @JoinColumn()
  address: Address;

  @IsOptional()
  @OneToMany(type => Agreement, agreement => agreement.farm, { nullable: true })
  agreements?: Agreement[];

  @IsOptional()
  @OneToMany(type => UserFarmer, userFarmer => userFarmer.farm, { nullable: true })
  farmers?: UserFarmer[];

  @IsOptional()
  @ManyToMany(type => UserConsultant, userConsultant => userConsultant.farms, { nullable: true })
  @JoinTable({ name: 'farm_consultant' })
  consultants?: UserConsultant[];

  @IsOptional()
  @ManyToOne(type => DairyCompany, dairyCompany => dairyCompany.farms, { nullable: true })
  dairyCompany?: DairyCompany;

  @IsOptional()
  @OneToMany(type => Expense, expense => expense.farm, { nullable: true })
  expenses?: Expense[];

  @IsOptional()
  @OneToMany(type => InventoryItem, inventoryItem => inventoryItem.farm, { nullable: true })
  inventoryItems?: InventoryItem[];

  @IsOptional()
  @OneToMany(type => Animal, animal => animal.farm, { nullable: true })
  animals?: Animal[];

  @IsOptional()
  @OneToMany(type => Revenue, revenue => revenue.farm, { nullable: false })
  revenues?: Revenue[];
}
